# SLLM - 説明執筆中 (under construction)

## simple LLM interface
```python
import SLLM

print(SLLM("ずばり簡潔に、タコの足は何本？"))
```

## 概要
- 非常にシンプルなコードでLLMが使えるツール

## 最も基本的な使い方
```python
import SLLM

print(SLLM("ずばり簡潔に、タコの足は何本？"))
```

## 名前の意味
- Simple-LLM-interfaceの意
